layout_size

Function layout_size 

pub const fn layout_size(capacity: u16, element_size: u32) -> usize
Compute total bytes needed in memory for a sparse array. Used for code generator to know how much space to reserve.